import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:meta/meta.dart';
import 'package:vegigo2_ui_common/entities/store/time_interval.dart';
import 'package:vegigo2_ui_common/util/constants.dart';

class DeliveryOption extends Equatable {
  final int id;
  final DeliveryOptionType type;
  final TimeInterval timeSlot;
  final Duration duration;

  DeliveryOption({@required this.id, this.type, this.timeSlot, this.duration});

  String asString({String delimiter = '-'}) {
    switch(this.type){
      case DeliveryOptionType.FIXED_DURATION: {
        return '${this.duration.inMinutes.toString()} minutes';
      }
      case DeliveryOptionType.TIME_SLOT: {
        return this.timeSlot.asString(delimiter: delimiter);
      }
      default: return '';
    }
  }

  @override
  List<Object> get props => [id, type, timeSlot, duration];
}

enum DeliveryOptionType {
  FIXED_DURATION,
  TIME_SLOT 
}

extension Utilities on DeliveryOptionType {
  String get displayValue {
    switch(this){
      case DeliveryOptionType.FIXED_DURATION: return Constants.INSTANT_DELIVERY_LABEL;
      case DeliveryOptionType.TIME_SLOT: return Constants.SLOT_DELIVERY_LABEL;
      default: return '';
    }
  }
}