import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/theme_gradient.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;

class CustomRadioWidget<T> extends StatelessWidget {
  final T value;
  final bool isSelected;
  final ValueChanged<T> onChanged;
  final double width;
  final double height;
  final String text;
  final TextStyle style;
  final double textWidth;

  CustomRadioWidget({
    @required this.value,
    this.isSelected = false,
    @required this.onChanged,
    this.width = 18,
    this.height = 18,
    @required this.text,
    @required this.style,
    this.textWidth});

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 10.0, vertical: 6.0),
      child: GestureDetector(
        onTap: () => onChanged(this.value),
        child: buildBody(context),
      ),
    );
  }

  Widget buildBody(BuildContext context) {
    return Row(mainAxisAlignment: MainAxisAlignment.start, children: <Widget>[
      if (isSelected == true)
        Container(
          height: this.height,
          width: this.width,
          decoration: ShapeDecoration(
            shape: CircleBorder(),
            gradient: ThemeGradient(context: context),
          ),
          child: Center(
            child: Container(
              height: this.height - 4,
              width: this.width - 4,
              decoration: ShapeDecoration(
                shape: CircleBorder(),
                color: Colors.white,
              ),
              child: Center(
                child: Container(
                  height: this.height - 8,
                  width: this.width - 8,
                  decoration: ShapeDecoration(
                    shape: CircleBorder(),
                    gradient: ThemeGradient(context: context),
                  ),
                ),
              ),
            ),
          ),
        )
      else
        Container(
          height: this.height,
          width: this.width,
          decoration: ShapeDecoration(shape: CircleBorder(), color: colors.LIGHT_GREY_2),
        ),
      Container(
        width: textWidth == null ? MediaQuery.of(context).size.width * 0.3 : textWidth,
        padding: const EdgeInsets.only(left: 8.0),
        child: Text(
          text,
          style: style,
        ),
      ),
    ]);
  }
}
