import 'package:flutter/material.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';

class GeoLocationView extends StatelessWidget {
  final LatLng latLng;
  final double zoom;
  final CameraPositionCallback onCameraMove;
  final ArgumentCallback<LatLng> onMarkerPositionChanged;

  GeoLocationView({
    @required this.latLng,
    this.zoom = 18,
    @required this.onCameraMove,
    @required this.onMarkerPositionChanged,
  });

  @override
  Widget build(BuildContext context) {
    return GoogleMap(
      markers: _createMarker(),
      onMapCreated: (GoogleMapController controller) {},
      initialCameraPosition: CameraPosition(target: latLng, zoom: zoom),
      onCameraMove: onCameraMove,
      onTap: onMarkerPositionChanged,
    );
  }

  Set<Marker> _createMarker() {
    return <Marker>[
      Marker(
        draggable: true,
        markerId: MarkerId(latLng.toString()),
        position: latLng,
        onDragEnd: onMarkerPositionChanged,
      )
    ].toSet();
  }
}
